@@ -8,6 +8,8 @@ from .core.pair import Pair
 from .core.trio import Trio
 from .eigval.eigenM import EigenM
 from .eigval.eig3dM import Eig3dM
+from .eigval.transM import TransM
+from .eigval.crossM import CrossM
 from .core import core
 from .core import geom
 from .core.window import Window
