@@ -215,7 +215,7 @@ class EigenM:
     
     def srcpol(self):
         # recover source polarisation
-        return self.data_corr().pol()
+        return self.data_corr().get_pol()
         
     def snrRH(self):
         """Restivo and Helffrich (1999) signal to noise ratio"""
